@@ -27,10 +27,14 @@ THEME_ICON_NAME = "variety-indicator"
 THEME_ICON_NAME_DARK = "variety-indicator-dark"
 
 try:
+    import gi
+    gi.require_version('AppIndicator3', '0.1')
     from gi.repository import AppIndicator3 # pylint: disable=E0611
     use_appindicator = True
 except ImportError:
     use_appindicator = False
+except ValueError:
+    use_appindicator = False
 
 from variety_lib import varietyconfig
 
@@ -316,14 +320,11 @@ class Indicator:
         self.status_icon = None
         self.visible = True
 
-        def pos(menu, x, y, icon):
-            return Gtk.StatusIcon.position_menu(self.menu, x, y, icon)
-
         def right_click_event(icon, button, time):
-            self.menu.popup(None, None, pos, self.status_icon, 0, time)
+            self.menu.popup(None, None, Gtk.StatusIcon.position_menu, self.status_icon, 0, time)
 
         def left_click_event(data):
-            self.menu.popup(None, None, pos, self.status_icon, 0, Gtk.get_current_event_time())
+            self.menu.popup(None, None, Gtk.StatusIcon.position_menu, self.status_icon, 0, Gtk.get_current_event_time())
 
         def on_indicator_scroll_status_icon(status_icon, event):
             window.on_indicator_scroll(None, 1, event.direction)
